@@ -9,6 +9,8 @@ from typing import List
 from numpy import nan
 from traceback import format_exc
 from logging import getLogger
+from copy import deepcopy
+from gc import collect
 
 log = getLogger(__name__)
 
@@ -50,6 +52,8 @@ class OpenPYXLReader(FileHandler):
                             sheets[tab] = xls_ws.max_row
             except:
                 pass
+            finally:
+                collect()
 
         return sheets
 
@@ -77,12 +81,15 @@ class OpenPYXLReader(FileHandler):
 
                                 xls_file.save(filename=file)
                             except Exception as e:
-                                log.error(format_exc)
+                                log.error(format_exc())
                                 log.error('Excel Sheet truncate Failed - Ecode {0}, {1}'.format(type(e).__name__,
                                                                                                 str(e)))
                                 pass
         except:
+            log.error(format_exc())
             pass
+        finally:
+            collect()
 
         if sheets:
             return sheets
@@ -116,7 +123,8 @@ class OpenPYXLReader(FileHandler):
                 if handler and buffer < len(data):
                     data = self.__read_only_fix(data, version, is_readonly)
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+                    handler(deepcopy(self.file_path), deepcopy(df), row_number - len(df) + 1,
+                            deepcopy(row_number), **self.kwargs)
                     data.clear()
                     data.append(header)
                     last_row_with_data = -1
@@ -130,7 +138,8 @@ class OpenPYXLReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+            handler(deepcopy(self.file_path), deepcopy(df), row_number - len(df) + 1,
+                    deepcopy(row_number), **self.kwargs)
         elif handler is None:
             return df
 
@@ -215,6 +224,7 @@ class ODFReader(FileHandler):
                         sheets[tab] = self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
             self.__odf_file.close()
+            collect()
 
         if sheets:
             return sheets
@@ -276,7 +286,8 @@ class ODFReader(FileHandler):
                 if handler and buffer < len(table):
                     table = self.__fix_table(table)
                     df = self.convert_data(table)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+                    handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_number - len(df) + 1),
+                            deepcopy(row_number), **self.kwargs)
                     table.clear()
                     table.append(header)
 
@@ -288,7 +299,8 @@ class ODFReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+            handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_number - len(df) + 1), deepcopy(row_number),
+                    **self.kwargs)
         elif not handler:
             return df
 
@@ -421,6 +433,7 @@ class XLRDReader(FileHandler):
                         sheets[tab] = self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
             self.__xls_file = None
+            collect()
 
         if sheets:
             return sheets
@@ -443,7 +456,8 @@ class XLRDReader(FileHandler):
 
                 if handler and len(data) <= buffer:
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+                    handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_number - len(df) + 1),
+                            deepcopy(row_number), deepcopy(**self.kwargs))
                     data.clear()
                     data.append(header)
 
@@ -454,7 +468,8 @@ class XLRDReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+            handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_number - len(df) + 1),
+                    deepcopy(row_number, **self.kwargs))
         elif not handler:
             return df
 
@@ -535,6 +550,7 @@ class PYXLSBReader(FileHandler):
                         sheets[tab] = self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
             self.__xls_file.close()
+            collect()
 
         if sheets:
             return sheets
@@ -554,7 +570,8 @@ class PYXLSBReader(FileHandler):
 
                 if handler and buffer < len(data):
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+                    handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_number - len(df) + 1),
+                            deepcopy(row_number), **self.kwargs)
                     data.clear()
                     data.append(header)
 
@@ -565,7 +582,8 @@ class PYXLSBReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
+            handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_number - len(df) + 1), deepcopy(row_number),
+                    **self.kwargs)
         elif not handler:
             return df
 
@@ -586,7 +604,7 @@ class PYXLSBReader(FileHandler):
 @contextlib.contextmanager
 def load_workbook(file_path, *args, **kwargs):
     from openpyxl import load_workbook
-    from os.path import join
+    from os.path import join, basename
     from os import remove
 
     wb = load_workbook(file_path, *args, **kwargs)
