@@ -191,10 +191,17 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                 raise ValueError("'engine' %r is not an Engine instance of SQLAlchemy Engine" % engine)
             if self.engine_type == 'pyodbc' and not isinstance(engine, Engine2):
                 raise ValueError("'engine' %r is not an Engine instance of PYODBC Connection" % engine)
+            if not engine:
+                raise ValueError("'engine' failed to create connection {%s}" % self.__sql_config.gen_conn_str())
+
+            conn_engine, spid = self.__validate_engine(engine)
+
+            if conn_engine is None:
+                conn_engine = engine
+                spid = 0
 
-            engine, spid = self.__validate_engine(engine)
             log.debug('SQL Engine %s: Created connection (%s) on SPID %s', self.engine_id, str(self.__sql_config), spid)
-            return [engine, spid]
+            return [conn_engine, spid]
 
     def restore_to_pool(self, close_cursors=False):
         """
